package com.baidu.lbs.waimai

import android.app.Activity
import android.app.Dialog
import android.content.Context
import android.os.Bundle
import android.os.Handler
import android.view.View
import com.baidu.crabsdk.CrabSDK
import com.baidu.lbs.waimai.waimaihostutils.stat.StatReferManager
import com.baidu.lbs.waimai.waimaihostutils.utils.SystemBarUtils
import com.baidu.mobstat.StatService
import com.baidu.waimai.comuilib.widget.CustomProgressDialog
import org.jetbrains.anko.AnkoComponent
import org.jetbrains.anko.AnkoContext
import org.jetbrains.anko.AnkoLogger

/**
 * Created by lidu on 2018/1/16.
 */
abstract class BaseKActivity : Activity(),
        AnkoComponent<Context>, AnkoLogger {

    protected lateinit var loadingDialog: Dialog
    private val loadingHandler: Handler = Handler()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        loadingDialog = CustomProgressDialog.createDialog(this)

//        val startTime = System.currentTimeMillis()
        setContentView(createView(AnkoContext.create(this)))
//        info("Time consumed inflating views: " + (System.currentTimeMillis() - startTime))
    }

    /*
        子类可以选择使用DSL方式或者Inflate一个xml布局文件返回一个View
     */
    abstract override fun createView(ui: AnkoContext<Context>): View

    abstract fun getCurrentReference(): String?

    public fun showLoadingDialog() {
        showLoadingDialog(true)
    }

    public fun showLoadingDialog(canCancel: Boolean) {
        loadingHandler.post {
            // 可能存在某种情况下回收了activity，又重新create，导致无attach view
            try {
                if (!loadingDialog.isShowing) {
                    loadingDialog.setCanceledOnTouchOutside(canCancel)
                    loadingDialog.show()
                }
            } catch (e: Exception) {
                e.printStackTrace()
            }
        }
    }

    public fun dismissLoadingDialog() {
        loadingHandler.post {
            // 可能存在某种情况下回收了activity，又重新create，导致无attach view
            try {
                if (loadingDialog.isShowing) {
                    loadingDialog.dismiss()
                }
            } catch (e: Exception) {
                e.printStackTrace()
            }
        }

    }

    override fun onStart() {
        super.onStart()
        CrabSDK.doActivityStart(this)
        initSystemBar()
    }

    private fun initSystemBar() {
        SystemBarUtils.tintWhiteSystemBar(this)
    }

    override fun onResume() {
        StatService.onResume(this)
        CrabSDK.onResume(this)
        super.onResume()

        StatReferManager.getInstance().lastReference = getCurrentReference()
        StatReferManager.getInstance().setCurrentReference(getCurrentReference())
    }

    override fun onPause() {
        StatService.onPause(this)
        CrabSDK.onPause(this)
        super.onPause()
    }

    override fun onStop() {
        CrabSDK.doActivityStop(this)
        super.onStop()
    }

}